Please see [https://docs.mlcommons.org/cm4mlops/scripts/AI-ML-optimization/compile-model-for.qaic](https://docs.mlcommons.org/cm4mlops/scripts/AI-ML-optimization/compile-model-for.qaic) for the documentation of this CM script.
